@@ -1,7 +1,7 @@
 package Log::Any::App;
 
-our $DATE = '2015-06-08'; # DATE
-our $VERSION = '0.48'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.49'; # VERSION
 
 # i need this to run on centos 5.x. otherwise all my other servers are debian
 # 5.x and 6.x+ (perl 5.010).
@@ -11,7 +11,7 @@ use warnings;
 
 use File::Path qw(make_path);
 use File::Spec;
-use Log::Any 0.14;
+use Log::Any::IfLOG;
 use Log::Any::Adapter;
 
 
@@ -1141,7 +1141,7 @@ Log::Any::App - An easy way to use Log::Any in applications
 
 =head1 VERSION
 
-This document describes version 0.48 of Log::Any::App (from Perl distribution Log-Any-App), released on 2015-06-08.
+This document describes version 0.49 of Log::Any::App (from Perl distribution Log-Any-App), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
